assert_str_trim_all_eq

Macro assert_str_trim_all_eq 

macro_rules! assert_str_trim_all_eq {
    ($left:expr, $right:expr $(,)?) => { ... };
    ($left:expr, $right:expr, $($arg:tt)+) => { ... };
}
Asserts that multiline strings(&str or String) are identical after removing all whitespace (spaces, tabs, and line breaks, anywhere in the string). Useful for comparing minified and pretty-printed formats.

Examples

Test on equality of two strings ignoring all whitespace:

use assert_str::assert_str_trim_all_eq;
assert_str_trim_all_eq!("<html>\t \n\t<head> \n\t</head></html>",
    "<html><head></head></html>", "Responses should be equal");