assert_str_trim_all_ne

Macro assert_str_trim_all_ne 

macro_rules! assert_str_trim_all_ne {
    ($left:expr, $right:expr $(,)?) => { ... };
    ($left:expr, $right:expr, $($arg:tt)+) => { ... };
}
Asserts that multiline strings(&str or String) are not identical after removing all whitespace (spaces, tabs, and line breaks, anywhere in the string). Useful for comparing minified and pretty-printed formats.

Examples

Test on inequality of two strings ignoring all whitespace:

use assert_str::assert_str_trim_all_ne;
assert_str_trim_all_ne!("<html>\t \n\t<head> \n\t</head></html>",
    "<HTML><head></head></html>", "Responses should not be equal");